Clean a keys output to ensure only accepted species from GBIF and/or WCVP are being analysed
Source:R/clean_keys.R
clean_keys.RdClean a keys output to ensure only accepted species from GBIF and/or WCVP are being analysed
Arguments
- keys
data frame of GBIF and/or WCVP identifier keys, as produced by
get_name_keys(). Must have asourcesattribute indicating which sources are present (e.g."GBIF","WCVP", or both).- override_gbif_status
if TRUE it will ignore the check on taxonomic status as returned by GBIF i.e. SYNONYMS will be allowed.
- override_wcvp_status
if TRUE it will ignore the check on taxonomic status as returned by WCVP