Generate the assessments.csv file
Arguments
- unique_id
(character) Unique identifier.
- native_ranges
Data frame of native ranges used to calculate biogeographic realms. Pass
NULLto skip realm calculation.- wcvp_ipni_id
(character or NULL) WCVP IPNI identifiers used to generate distribution and habitat narrative text via POWO. Pass
NULLfor taxa without WCVP coverage (e.g. fungi), in which caseRangeDocumentation.narrativeandHabitatDocumentation.narrativewill be left blank.- occs
Occurrence data passed to
powo_text().